@@ -27,7 +27,7 @@ import sqlalchemy
 from sqlalchemy import Column, Integer, literal_column, select, String, Table, union
 from sqlalchemy.testing.assertions import eq_, in_
 
-from conftest import setup_table, sqlalchemy_1_3_or_higher
+from .conftest import setup_table, sqlalchemy_1_3_or_higher
 
 
 def assert_result(connection, sel, expected, params=()):
